==> huaweicloudsdksis-3.1.116-py2.py3-none-any.whl: huaweicloudsdksis/v1/model/show_vocabularies_request.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class ShowVocabulariesRequest:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'offset': 'int',
        'limit': 'int',
        'body': 'ShowVocabulariesParams'
    }

    attribute_map = {
        'offset': 'offset',
        'limit': 'limit',
        'body': 'body'
    }

    def __init__(self, offset=None, limit=None, body=None):
        """ShowVocabulariesRequest

        The model defined in huaweicloud sdk

        :param offset: 页码偏移量，表示从此页码偏移量开始查询，offset大于等于0。
        :type offset: int
        :param limit: 每页显示的条目数量。
        :type limit: int
        :param body: Body of the ShowVocabulariesRequest
        :type body: :class:`huaweicloudsdksis.v1.ShowVocabulariesParams`
        """
        
        

        self._offset = None
        self._limit = None
        self._body = None
        self.discriminator = None

        if offset is not None:
            self.offset = offset
        if limit is not None:
            self.limit = limit
        if body is not None:
            self.body = body

    @property
    def offset(self):
        """Gets the offset of this ShowVocabulariesRequest.

        页码偏移量，表示从此页码偏移量开始查询，offset大于等于0。

        :return: The offset of this ShowVocabulariesRequest.
        :rtype: int
        """
        return self._offset

    @offset.setter
    def offset(self, offset):
        """Sets the offset of this ShowVocabulariesRequest.

        页码偏移量，表示从此页码偏移量开始查询，offset大于等于0。

        :param offset: The offset of this ShowVocabulariesRequest.
        :type offset: int
        """
        self._offset = offset

    @property
    def limit(self):
        """Gets the limit of this ShowVocabulariesRequest.

        每页显示的条目数量。

        :return: The limit of this ShowVocabulariesRequest.
        :rtype: int
        """
        return self._limit

    @limit.setter
    def limit(self, limit):
        """Sets the limit of this ShowVocabulariesRequest.

        每页显示的条目数量。

        :param limit: The limit of this ShowVocabulariesRequest.
        :type limit: int
        """
        self._limit = limit

    @property
    def body(self):
        """Gets the body of this ShowVocabulariesRequest.

        :return: The body of this ShowVocabulariesRequest.
        :rtype: :class:`huaweicloudsdksis.v1.ShowVocabulariesParams`
        """
        return self._body

    @body.setter
    def body(self, body):
        """Sets the body of this ShowVocabulariesRequest.

        :param body: The body of this ShowVocabulariesRequest.
        :type body: :class:`huaweicloudsdksis.v1.ShowVocabulariesParams`
        """
        self._body = body

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ShowVocabulariesRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdksis-3.1.156-py2.py3-none-any.whl: huaweicloudsdksis/v1/model/show_vocabularies_request.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class ShowVocabulariesRequest:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'offset': 'int',
        'limit': 'int',
        'body': 'ShowVocabulariesParams'
    }

    attribute_map = {
        'offset': 'offset',
        'limit': 'limit',
        'body': 'body'
    }

    def __init__(self, offset=None, limit=None, body=None):
        r"""ShowVocabulariesRequest

        The model defined in huaweicloud sdk

        :param offset: 页码偏移量，表示从此页码偏移量开始查询，offset大于等于0。
        :type offset: int
        :param limit: 每页显示的条目数量。
        :type limit: int
        :param body: Body of the ShowVocabulariesRequest
        :type body: :class:`huaweicloudsdksis.v1.ShowVocabulariesParams`
        """
        
        

        self._offset = None
        self._limit = None
        self._body = None
        self.discriminator = None

        if offset is not None:
            self.offset = offset
        if limit is not None:
            self.limit = limit
        if body is not None:
            self.body = body

    @property
    def offset(self):
        r"""Gets the offset of this ShowVocabulariesRequest.

        页码偏移量，表示从此页码偏移量开始查询，offset大于等于0。

        :return: The offset of this ShowVocabulariesRequest.
        :rtype: int
        """
        return self._offset

    @offset.setter
    def offset(self, offset):
        r"""Sets the offset of this ShowVocabulariesRequest.

        页码偏移量，表示从此页码偏移量开始查询，offset大于等于0。

        :param offset: The offset of this ShowVocabulariesRequest.
        :type offset: int
        """
        self._offset = offset

    @property
    def limit(self):
        r"""Gets the limit of this ShowVocabulariesRequest.

        每页显示的条目数量。

        :return: The limit of this ShowVocabulariesRequest.
        :rtype: int
        """
        return self._limit

    @limit.setter
    def limit(self, limit):
        r"""Sets the limit of this ShowVocabulariesRequest.

        每页显示的条目数量。

        :param limit: The limit of this ShowVocabulariesRequest.
        :type limit: int
        """
        self._limit = limit

    @property
    def body(self):
        r"""Gets the body of this ShowVocabulariesRequest.

        :return: The body of this ShowVocabulariesRequest.
        :rtype: :class:`huaweicloudsdksis.v1.ShowVocabulariesParams`
        """
        return self._body

    @body.setter
    def body(self, body):
        r"""Sets the body of this ShowVocabulariesRequest.

        :param body: The body of this ShowVocabulariesRequest.
        :type body: :class:`huaweicloudsdksis.v1.ShowVocabulariesParams`
        """
        self._body = body

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ShowVocabulariesRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
